@@ -1,4 +1,3 @@
-import logging
 from threading import Thread
 
 from PyQt5.QtMultimedia import QMediaPlayer
@@ -10,14 +9,16 @@ from cracker.keylogger import KeyBoardManager
 from cracker.speaker.abstract_speaker import AbstractSpeaker
 from cracker.speaker.espeak import Espeak
 from cracker.speaker.polly import Polly
+from cracker.speaker.google import Google
 from cracker.text_parser import TextParser
+from cracker.utils import get_logger
 
 
 class Cracker(object):
     """Logic for running the Cracker program"""
 
-    SPEAKER = {Polly.__name__: Polly, Espeak.__name__: Espeak}
-    _logger = logging.getLogger(__name__)
+    SPEAKER = {Polly.__name__: Polly, Espeak.__name__: Espeak, Google.__name__: Google}
+    _logger = get_logger(__name__)
 
     def __init__(self, app: QApplication):
         super().__init__()
@@ -52,6 +53,9 @@ class Cracker(object):
                 return Polly(player, profile_name)
             else:
                 return Polly(player)
+        elif speaker_name == Google.__name__:
+            credentials_file = self.config.default_values.get("credentials_file", None)
+            return Google(player, credentials_file)
         elif speaker_name == Espeak.__name__:
             return Espeak(player)
         raise ValueError(f"No speaker was selected. Provided speaker name '{speaker_name}'")
@@ -90,6 +94,7 @@ class Cracker(object):
 
     def toggle_read_text_clipboard(self):
         """Reads out text from the clipboard with selected speaker."""
+        self._logger.debug("Reading text from clipboard")
         if self.player.state() == QMediaPlayer.PlayingState:
             self.stop_text()
             self.player.stop()
@@ -102,6 +107,7 @@ class Cracker(object):
             self._read(text)
 
     def _read(self, text):
+        self._logger.debug(f"Reading text: {text}")
         speaker_config = self._prepare_config()
         self._last_pid = self.speaker.read_text(text, **speaker_config)
 
